const {Admin} = require('../../../../dao/models');
const Joi = require('joi');
const ApplicationError = require('../../../../utils/application-error');
/**
* @module An object to autorizate the administrator.
* @type {Object}
* @property {string} method - HTTP method (post).
* @property {string} path - The path to process the request.
* @property {Joi.ObjectSchema} validationSchema - Input validation scheme.
* @property {Array} middlewares - Middlewares that can be applied to the request processing (empty array).
* @property {Function} handler - The function that handles the request.
* @async
* @param {Object} req - The request object.
* @param {Object} res - Response object.
* @returns {Object} - An object that contains information.
* @throws {Error} - An exception if an error occurred while processing the request.
*/
module.exports = {
  method: 'post',
  path: '/login/admin',
  validationSchema: Joi.object({
    email: Joi.string().required(),
    password: Joi.string().required()
  }),
  middlewares: [],
  handler: async function (req, res) {
    const admin = await Admin.scope('auth').findOne({where: {email: req.body.email}});
    if (!admin) {
      throw ApplicationError.NotFound();
    }
    return await admin.authenticateByPassword(req.body.password);
  }
};
