const {User} = require('../../../../dao/models');
const Joi = require('joi');
const ApplicationError = require('../../../../utils/application-error');
/**
* @module An object representing the Post HTTP method for user authorization.
* @type {Object}
* @property {string} method - HTTP method (post).
* @property {string} path - Path to process the request ("/login").
* @property {Joi.ObjectSchema} validationSchema - Input validation scheme.
* @property {Array} middlewares - Middleware that can be used to process the request (empty array).
* @property {Function} handler - The function that handles the request for user authorization.
* @async
* @param {Object} req - Request object.
* @param {Object} res - Response object.
* @returns {Object} - An object containing user data after authorization.
* @throws {Error} - Exception if an error occurred during authorization.
*/

module.exports = {
  method: 'post',
  path: '/login',
  validationSchema: Joi.object({
    email: Joi.string().required(),
    password: Joi.string().required(),
  }),
  middlewares: [],
  handler: async function (req, res) {
    const user = await User.scope('auth').findOne({where: {email: req.body.email}});
    if (!user) {
      throw ApplicationError.NotFound();
    }
    return await user.authenticateByPassword(req.body.password);
  }
};
