'use strict';

var Sequelize = require('sequelize');

/**
 * Actions summary:
 *
 * createTable "Admin", deps: []
 * createTable "User", deps: []
 *
 **/

var info = {
    "revision": 1,
    "name": "auto-migration",
    "created": "2023-12-05T16:14:52.852Z",
    "comment": ""
};

var migrationCommands = function(transaction) {
    return [{
            fn: "createTable",
            params: [
                "Admin",
                {
                    "id": {
                        "type": Sequelize.INTEGER,
                        "field": "id",
                        "autoIncrement": true,
                        "primaryKey": true,
                        "allowNull": false
                    },
                    "email": {
                        "type": Sequelize.STRING,
                        "field": "email",
                        "allowNull": false,
                        "unique": true
                    },
                    "passwordHashed": {
                        "type": Sequelize.STRING,
                        "field": "passwordHashed",
                        "allowNull": false,
                        "unique": false
                    },
                    "salt": {
                        "type": Sequelize.STRING,
                        "field": "salt",
                        "allowNull": false,
                        "unique": false
                    },
                    "refreshToken": {
                        "type": Sequelize.STRING,
                        "field": "refreshToken",
                        "allowNull": true,
                        "unique": false
                    },
                    "createdAt": {
                        "type": Sequelize.DATE,
                        "field": "createdAt",
                        "allowNull": false
                    },
                    "updatedAt": {
                        "type": Sequelize.DATE,
                        "field": "updatedAt",
                        "allowNull": false
                    }
                },
                {
                    "transaction": transaction
                }
            ]
        },
        {
            fn: "createTable",
            params: [
                "User",
                {
                    "id": {
                        "type": Sequelize.INTEGER,
                        "field": "id",
                        "autoIncrement": true,
                        "primaryKey": true,
                        "allowNull": false
                    },
                    "email": {
                        "type": Sequelize.STRING,
                        "field": "email",
                        "allowNull": false,
                        "unique": true
                    },
                    "passwordHashed": {
                        "type": Sequelize.STRING,
                        "field": "passwordHashed",
                        "allowNull": false,
                        "unique": false
                    },
                    "salt": {
                        "type": Sequelize.STRING,
                        "field": "salt",
                        "allowNull": false,
                        "unique": false
                    },
                    "refreshToken": {
                        "type": Sequelize.STRING,
                        "field": "refreshToken",
                        "allowNull": true,
                        "unique": false
                    },
                    "createdAt": {
                        "type": Sequelize.DATE,
                        "field": "createdAt",
                        "allowNull": false
                    },
                    "updatedAt": {
                        "type": Sequelize.DATE,
                        "field": "updatedAt",
                        "allowNull": false
                    }
                },
                {
                    "transaction": transaction
                }
            ]
        }
    ];
};
var rollbackCommands = function(transaction) {
    return [{
            fn: "dropTable",
            params: ["Admin", {
                transaction: transaction
            }]
        },
        {
            fn: "dropTable",
            params: ["User", {
                transaction: transaction
            }]
        }
    ];
};

module.exports = {
    pos: 0,
    useTransaction: true,
    execute: function(queryInterface, Sequelize, _commands)
    {
        var index = this.pos;
        function run(transaction) {
            const commands = _commands(transaction);
            return new Promise(function(resolve, reject) {
                function next() {
                    if (index < commands.length)
                    {
                        let command = commands[index];
                        console.log("[#"+index+"] execute: " + command.fn);
                        index++;
                        queryInterface[command.fn].apply(queryInterface, command.params).then(next, reject);
                    }
                    else
                        resolve();
                }
                next();
            });
        }
        if (this.useTransaction) {
            return queryInterface.sequelize.transaction(run);
        } else {
            return run(null);
        }
    },
    up: function(queryInterface, Sequelize)
    {
        return this.execute(queryInterface, Sequelize, migrationCommands);
    },
    down: function(queryInterface, Sequelize)
    {
        return this.execute(queryInterface, Sequelize, rollbackCommands);
    },
    info: info
};
