const fs = require('fs');
const path = require('path');
const Controller = require('../api/Controller');

const getDirsAndFileLists = (dirname) => {
  const data = {};
  const items = fs.readdirSync(dirname, { withFileTypes: true });
  const files = [];

  items.forEach((item) => {
    if (item.isDirectory()) {
      const subdata = getDirsAndFileLists(path.join(dirname, item.name));
      Object.assign(data, subdata);
    } else {
      files.push(item.name);
    }
  });

  data[dirname] = files;

  return data;
};

/**
* @module Module for dynamic loading and registration of controllers in the router.
*
* This module scans the specified directory and its subdirectories for controllers,
* downloads them, and registers them in the transferred router.
*
* @param {string} dirname - The path to the directory where the controllers are located.
* @param {string} prefix - Prefix for the path of the controllers.
* @param {Object} router - The router object to register the controllers.
*/
module.exports = (dirname, prefix, router) => {
  const dirsAndFiles = getDirsAndFileLists(path.join(dirname, "controllers"));

  for (let dir in dirsAndFiles) {
    dirsAndFiles[dir].forEach((fileName) => {
      const controllerParams = require(path.join(dir, fileName));
      controllerParams.path = prefix + controllerParams.path;
      const controller = new Controller(controllerParams);
      controller.register(router);
    });
  }
};
